@@ -2016,19 +2016,18 @@ static gboolean
 blow_expensive_caches (gpointer data)
 {
 	MateBG *bg = data;
-	GList *list;
+	GList *list, *next;
 
 	bg->blow_caches_id = 0;
 
-	if (bg->file_cache) {
-		for (list = bg->file_cache; list != NULL; list = list->next) {
-			FileCacheEntry *ent = list->data;
+	for (list = bg->file_cache; list != NULL; list = next) {
+		FileCacheEntry *ent = list->data;
+		next = list->next;
 
-			if (ent->type == PIXBUF) {
-				file_cache_entry_delete (ent);
-				bg->file_cache = g_list_delete_link (bg->file_cache,
-								     list);
-			}
+		if (ent->type == PIXBUF) {
+			file_cache_entry_delete (ent);
+			bg->file_cache = g_list_delete_link (bg->file_cache,
+							     list);
 		}
 	}
 
@@ -3197,9 +3196,13 @@ mate_bg_changes_with_time (MateBG *bg)
 	if (!bg->filename)
 		return FALSE;
 
-	show = get_as_slideshow (bg, bg->filename);
-	if (show)
-		return g_queue_get_length (show->slides) > 1;
+	if ((show = get_as_slideshow (bg, bg->filename)) != NULL) {
+		gboolean result;
+
+		result = (g_queue_get_length (show->slides) > 1) ? TRUE : FALSE;
+		slideshow_unref (show);
+		return result;
+	}
 
 	return FALSE;
 }
