@@ -1250,6 +1250,7 @@ palette_set_color (GtkWidget         *drawing_area,
 		   MateColorSelection *colorsel,
 		   gdouble           *color)
 {
+  gpointer pointer;
   gdouble *new_color = g_new (double, 4);
   GdkRGBA  box_color;
 
@@ -1260,7 +1261,8 @@ palette_set_color (GtkWidget         *drawing_area,
 
   override_background_color (drawing_area, &box_color);
 
-  if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (drawing_area), "color_set")) == 0)
+  pointer = g_object_get_data (G_OBJECT (drawing_area), "color_set");
+  if (!pointer || GPOINTER_TO_INT (pointer) == 0)
     {
       static const GtkTargetEntry targets[] = {
 	{ "application/x-color", 0 }
@@ -1458,7 +1460,8 @@ palette_release (GtkWidget      *drawing_area,
       g_object_get_data (G_OBJECT (drawing_area),
 			 "gtk-colorsel-have-pointer") != NULL)
     {
-      if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (drawing_area), "color_set")) != 0)
+      gpointer pointer = g_object_get_data (G_OBJECT (drawing_area), "color_set");
+      if (pointer && GPOINTER_TO_INT (pointer) != 0)
         {
           gdouble color[4];
           palette_get_color (drawing_area, color);
@@ -1517,7 +1520,8 @@ palette_activate (GtkWidget   *widget,
       (event->keyval == GDK_KEY_KP_Enter) ||
       (event->keyval == GDK_KEY_KP_Space))
     {
-      if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "color_set")) != 0)
+      gpointer pointer = g_object_get_data (G_OBJECT (widget), "color_set");
+      if (pointer && GPOINTER_TO_INT (pointer) != 0)
         {
           gdouble color[4];
           palette_get_color (widget, color);
@@ -1624,6 +1628,17 @@ make_picker_cursor (GdkScreen *screen)
   return cursor;
 }
 
+static GdkDevice *get_device (GdkDisplay *display)
+{
+  GdkSeat   *seat;
+  GdkDevice *device;
+
+  seat = gdk_display_get_default_seat (display);
+  device = gdk_seat_get_pointer (seat);
+
+  return device;
+}
+
 static void
 grab_color_at_mouse (GdkScreen *screen,
 		     gint       x_root,
@@ -1645,8 +1660,10 @@ grab_color_at_mouse (GdkScreen *screen,
   if (!pixbuf)
     {
       gint x, y;
+      GdkDevice *device;
       GdkDisplay *display = gdk_screen_get_display (screen);
-      GdkWindow *window = gdk_display_get_window_at_pointer (display, &x, &y);
+      device = get_device (display);
+      GdkWindow *window = gdk_device_get_window_at_position (device, &x, &y);
       if (!window)
 	return;
       pixbuf = gdk_pixbuf_get_from_window (window,
@@ -1681,14 +1698,14 @@ shutdown_eyedropper (GtkWidget *widget)
   MateColorSelection *colorsel;
   MateColorSelectionPrivate *priv;
   GdkDisplay *display = gtk_widget_get_display (widget);
+  GdkSeat   *seat = gdk_display_get_default_seat (display);
 
   colorsel = MATE_COLOR_SELECTION (widget);
   priv = colorsel->private_data;
 
   if (priv->has_grab)
     {
-      gdk_display_keyboard_ungrab (display, priv->grab_time);
-      gdk_display_pointer_ungrab (display, priv->grab_time);
+      gdk_seat_ungrab (seat);
       gtk_grab_remove (priv->dropper_grab_widget);
 
       priv->has_grab = FALSE;
@@ -1736,13 +1753,15 @@ key_press (GtkWidget   *invisible,
            GdkEventKey *event,
            gpointer     data)
 {
+  GdkDevice *device;
   GdkDisplay *display = gtk_widget_get_display (invisible);
   GdkScreen *screen = gdk_event_get_screen ((GdkEvent *)event);
   guint state = event->state & gtk_accelerator_get_default_mod_mask ();
   gint x, y;
   gint dx, dy;
 
-  gdk_display_get_pointer (display, NULL, &x, &y, NULL);
+  device = get_device (display);
+  gdk_device_get_position (device, NULL, &x, &y);
 
   dx = 0;
   dy = 0;
@@ -1795,7 +1814,7 @@ key_press (GtkWidget   *invisible,
       return FALSE;
     }
 
-  gdk_display_warp_pointer (display, screen, x + dx, y + dy);
+  gdk_device_warp (device, screen, x + dx, y + dy);
 
   return TRUE;
 
@@ -1839,9 +1858,12 @@ get_screen_color (GtkWidget *button)
   GdkCursor *picker_cursor;
   GdkGrabStatus grab_status;
   GtkWidget *grab_widget, *toplevel;
+  GdkDisplay *display;
+  GdkEvent   *event;
+  GdkSeat    *seat;
 
   guint32 time = gtk_get_current_event_time ();
-
+  event = gtk_get_current_event ();
   if (priv->dropper_grab_widget == NULL)
     {
       grab_widget = gtk_window_new (GTK_WINDOW_POPUP);
@@ -1865,22 +1887,29 @@ get_screen_color (GtkWidget *button)
       priv->dropper_grab_widget = grab_widget;
     }
 
-  if (gdk_keyboard_grab (gtk_widget_get_window (priv->dropper_grab_widget),
-                         FALSE, time) != GDK_GRAB_SUCCESS)
+  display = gtk_widget_get_display (priv->dropper_grab_widget);
+  seat = gdk_display_get_default_seat (display);
+
+  if (gdk_seat_grab (seat, gtk_widget_get_window (priv->dropper_grab_widget),
+                     GDK_SEAT_CAPABILITY_KEYBOARD, FALSE, NULL,
+                     event,
+                     NULL, NULL) != GDK_GRAB_SUCCESS)
+  {
+    gdk_event_free (event);
     return;
+  }
 
   picker_cursor = make_picker_cursor (screen);
-  grab_status = gdk_pointer_grab (gtk_widget_get_window (priv->dropper_grab_widget),
-				  FALSE,
-				  GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK,
-				  NULL,
-				  picker_cursor,
-				  time);
+  grab_status = gdk_seat_grab (seat, gtk_widget_get_window (priv->dropper_grab_widget),
+                               GDK_SEAT_CAPABILITY_POINTER, FALSE, picker_cursor,
+                               event,
+                               NULL, NULL);
+  gdk_event_free (event);
   g_object_unref (picker_cursor);
 
   if (grab_status != GDK_GRAB_SUCCESS)
     {
-      gdk_display_keyboard_ungrab (gtk_widget_get_display (button), time);
+      gdk_seat_ungrab (seat);
       return;
     }
 
@@ -2127,6 +2156,9 @@ update_color (MateColorSelection *colorsel)
   gchar entryval[12];
   gchar opacity_text[32];
   gchar *ptr;
+  double r;
+  double g;
+  double b;
 
   priv->changing = TRUE;
   color_sample_update_samples (colorsel);
@@ -2160,10 +2192,10 @@ update_color (MateColorSelection *colorsel)
   g_snprintf (opacity_text, 32, "%.0f", scale_round (priv->color[COLORSEL_OPACITY], 255));
   gtk_entry_set_text (GTK_ENTRY (priv->opacity_entry), opacity_text);
 
-  g_snprintf (entryval, 11, "#%2X%2X%2X",
-	      (guint) (scale_round (priv->color[COLORSEL_RED], 255)),
-	      (guint) (scale_round (priv->color[COLORSEL_GREEN], 255)),
-	      (guint) (scale_round (priv->color[COLORSEL_BLUE], 255)));
+  r = scale_round (priv->color[COLORSEL_RED],   255);
+  g = scale_round (priv->color[COLORSEL_GREEN], 255);
+  b = scale_round (priv->color[COLORSEL_BLUE],  255);
+  g_snprintf (entryval, 11, "#%2X%2X%2X", (guint) r, (guint) g, (guint) b);
 
   for (ptr = entryval; *ptr; ptr++)
     if (*ptr == ' ')
