@@ -370,19 +370,26 @@ locale_dir_has_mo_files (const gchar* path)
 gboolean
 mate_language_has_translations (const char *code)
 {
-        gboolean     has_translations;
-        gchar *path = NULL;
+        gboolean has_translations;
+        gchar *path;
 
         path = g_build_filename (MATELOCALEDIR, code, "LC_MESSAGES", NULL);
         has_translations = locale_dir_has_mo_files (path);
 
         if (!has_translations) {
-            g_free(path);
-            path = g_build_filename ("/usr/share/locale", code, "LC_MESSAGES", NULL);
-            has_translations = locale_dir_has_mo_files (path);
+                const char * const *system_data_dirs;
+                int i = 0;
+
+                system_data_dirs = g_get_system_data_dirs ();
+                while ((system_data_dirs[i] != NULL) && (has_translations == FALSE)) {
+                        g_free (path);
+                        path = g_build_filename (system_data_dirs[i], "locale", code, "LC_MESSAGES", NULL);
+                        has_translations = locale_dir_has_mo_files (path);
+                        ++i;
+                }
         }
 
-        g_free(path);
+        g_free (path);
         return has_translations;
 }
 
@@ -548,6 +555,24 @@ collect_locales_from_localebin (void)
         return found_locales;
 }
 
+static void
+fill_count_map (GHashTable *count_map,
+                const char *code)
+{
+        int count;
+        gpointer pointer;
+
+        if (code == NULL)
+                return;
+
+        if ((pointer = g_hash_table_lookup (count_map, code)) != NULL)
+                count = GPOINTER_TO_INT (pointer) + 1;
+        else
+                count = 1;
+
+        g_hash_table_insert (count_map, g_strdup (code), GINT_TO_POINTER (count));
+}
+
 static void
 count_languages_and_territories (void)
 {
@@ -559,25 +584,9 @@ count_languages_and_territories (void)
 
         g_hash_table_iter_init (&iter, mate_available_locales_map);
         while (g_hash_table_iter_next (&iter, NULL, &value)) {
-                MateLocale *locale;
-
-                locale = (MateLocale *) value;
-
-		if (locale->language_code != NULL) {
-			int count;
-
-			count = GPOINTER_TO_INT (g_hash_table_lookup (mate_language_count_map, locale->language_code));
-			count++;
-			g_hash_table_insert (mate_language_count_map, g_strdup (locale->language_code), GINT_TO_POINTER (count));
-		}
-
-		if (locale->territory_code != NULL) {
-			int count;
-
-			count = GPOINTER_TO_INT (g_hash_table_lookup (mate_territory_count_map, locale->territory_code));
-			count++;
-			g_hash_table_insert (mate_territory_count_map, g_strdup (locale->territory_code), GINT_TO_POINTER (count));
-		}
+                MateLocale *locale = (MateLocale *) value;
+                fill_count_map (mate_language_count_map, locale->language_code);
+                fill_count_map (mate_territory_count_map, locale->territory_code);
         }
 }
 
@@ -607,11 +616,16 @@ collect_locales (void)
 static gint
 get_language_count (const char *language)
 {
-        if (mate_language_count_map == NULL) {
-                collect_locales ();
-        }
+        gint count = 0;
+        gpointer pointer;
 
-	return GPOINTER_TO_INT (g_hash_table_lookup (mate_language_count_map, language));
+        if (mate_language_count_map == NULL)
+                collect_locales ();
+
+        if ((pointer = g_hash_table_lookup (mate_language_count_map, language)) != NULL)
+                count = GPOINTER_TO_INT (pointer);
+
+        return count;
 }
 
 static gboolean
@@ -623,11 +637,16 @@ is_unique_language (const char *language)
 static gint
 get_territory_count (const char *territory)
 {
-        if (mate_territory_count_map == NULL) {
-                collect_locales ();
-        }
+        gint count = 0;
+        gpointer pointer;
 
-	return GPOINTER_TO_INT (g_hash_table_lookup (mate_territory_count_map, territory));
+        if (mate_territory_count_map == NULL)
+                collect_locales ();
+
+        if ((pointer = g_hash_table_lookup (mate_territory_count_map, territory)) != NULL)
+                count = GPOINTER_TO_INT (pointer);
+
+        return count;
 }
 
 static gboolean
